# Utility and View

Utility commands are used to do the following:

- Create SymbolicConstant and Boolean objects.
- Change the name of a key to a Repository object.
- Control the use of deprecated commands.
- Request input from the user.
- Display status information.
- Execute Python commands or functions.
- Register a callback that will be invoked when certain Abaqus Scripting Interface commands are about to be executed.
- Register a callback that will be invoked when certain Abaqus Scripting Interface objects are about to be deleted.
- Upgrade Abaqus kernel or GUI scripts from one release of Abaqus to a later release.

View commands are used to transform three-dimensional views stored in Session and Viewport objects to the screen. (See Session object and Viewport object.)

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.UtilityAndView
        :recursive:
```
